@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class DescribeCheckFixDetailsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeCheckFixDetails')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeCheckFixDetails','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class DescribeCheckFixDetailsRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
 	def get_CheckIds(self): # String
 		return self.get_query_params().get('CheckIds')
 
@@ -41,8 +46,3 @@ class DescribeCheckFixDetailsRequest(RpcRequest):
 
 	def set_RiskId(self, RiskId):  # Long
 		self.add_query_param('RiskId', RiskId)
-	def get_Lang(self): # String
-		return self.get_query_params().get('Lang')
-
-	def set_Lang(self, Lang):  # String
-		self.add_query_param('Lang', Lang)
