@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class DescribeClientConfStrategyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeClientConfStrategy')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeClientConfStrategy','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,13 +31,13 @@ class DescribeClientConfStrategyRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_TagValue(self): # String
-		return self.get_query_params().get('TagValue')
-
-	def set_TagValue(self, TagValue):  # String
-		self.add_query_param('TagValue', TagValue)
 	def get_Tag(self): # String
 		return self.get_query_params().get('Tag')
 
 	def set_Tag(self, Tag):  # String
 		self.add_query_param('Tag', Tag)
+	def get_TagValue(self): # String
+		return self.get_query_params().get('TagValue')
+
+	def set_TagValue(self, TagValue):  # String
+		self.add_query_param('TagValue', TagValue)
