@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class DescribeHoneyPotSuspStatisticsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeHoneyPotSuspStatistics')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeHoneyPotSuspStatistics','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,13 +36,18 @@ class DescribeHoneyPotSuspStatisticsRequest(RpcRequest):
 
 	def set_StatisticsDays(self, StatisticsDays):  # Integer
 		self.add_query_param('StatisticsDays', StatisticsDays)
-	def get_StatisticsKeyType(self): # String
-		return self.get_query_params().get('StatisticsKeyType')
-
-	def set_StatisticsKeyType(self, StatisticsKeyType):  # String
-		self.add_query_param('StatisticsKeyType', StatisticsKeyType)
 	def get_From(self): # String
 		return self.get_query_params().get('From')
 
 	def set_From(self, _From):  # String
 		self.add_query_param('From', _From)
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_StatisticsKeyType(self): # String
+		return self.get_query_params().get('StatisticsKeyType')
+
+	def set_StatisticsKeyType(self, StatisticsKeyType):  # String
+		self.add_query_param('StatisticsKeyType', StatisticsKeyType)
