@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class DescribeSimilarSecurityEventsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeSimilarSecurityEvents')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeSimilarSecurityEvents','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,11 +36,6 @@ class DescribeSimilarSecurityEventsRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
-	def get_CurrentPage(self): # Integer
-		return self.get_query_params().get('CurrentPage')
-
-	def set_CurrentPage(self, CurrentPage):  # Integer
-		self.add_query_param('CurrentPage', CurrentPage)
 	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
@@ -61,3 +56,8 @@ class DescribeSimilarSecurityEventsRequest(RpcRequest):
 
 	def set_TaskId(self, TaskId):  # Long
 		self.add_query_param('TaskId', TaskId)
+	def get_CurrentPage(self): # Integer
+		return self.get_query_params().get('CurrentPage')
+
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
