@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class ExportRecordRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ExportRecord')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ExportRecord','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class ExportRecordRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
 	def get_ExportType(self): # String
 		return self.get_query_params().get('ExportType')
 
@@ -41,8 +46,3 @@ class ExportRecordRequest(RpcRequest):
 
 	def set_Params(self, Params):  # String
 		self.add_query_param('Params', Params)
-	def get_Lang(self): # String
-		return self.get_query_params().get('Lang')
-
-	def set_Lang(self, Lang):  # String
-		self.add_query_param('Lang', Lang)
