@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class GetModuleConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'GetModuleConfig')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'GetModuleConfig','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,13 +31,13 @@ class GetModuleConfigRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_CurrentPage(self): # String
-		return self.get_query_params().get('CurrentPage')
-
-	def set_CurrentPage(self, CurrentPage):  # String
-		self.add_query_param('CurrentPage', CurrentPage)
 	def get_PageSize(self): # String
 		return self.get_query_params().get('PageSize')
 
 	def set_PageSize(self, PageSize):  # String
 		self.add_query_param('PageSize', PageSize)
+	def get_CurrentPage(self): # String
+		return self.get_query_params().get('CurrentPage')
+
+	def set_CurrentPage(self, CurrentPage):  # String
+		self.add_query_param('CurrentPage', CurrentPage)
