@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class HandleSimilarSecurityEventsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'HandleSimilarSecurityEvents')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'HandleSimilarSecurityEvents','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -41,6 +41,11 @@ class HandleSimilarSecurityEventsRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Remark(self): # String
+		return self.get_query_params().get('Remark')
+
+	def set_Remark(self, Remark):  # String
+		self.add_query_param('Remark', Remark)
 	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
