@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class ListPrivateRegistryTypeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListPrivateRegistryType')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListPrivateRegistryType','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,3 +31,8 @@ class ListPrivateRegistryTypeRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
