@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class ListSystemRuleAggregationTypesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListSystemRuleAggregationTypes')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListSystemRuleAggregationTypes','sas')
 		self.set_method('GET')
 
 		if hasattr(self, "endpoint_map"):
