@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class ListUuidsByWebPathRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListUuidsByWebPath')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ListUuidsByWebPath','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,11 +36,6 @@ class ListUuidsByWebPathRequest(RpcRequest):
 
 	def set_WebPath(self, WebPath):  # String
 		self.add_query_param('WebPath', WebPath)
-	def get_CurrentPage(self): # Integer
-		return self.get_query_params().get('CurrentPage')
-
-	def set_CurrentPage(self, CurrentPage):  # Integer
-		self.add_query_param('CurrentPage', CurrentPage)
 	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
@@ -51,3 +46,8 @@ class ListUuidsByWebPathRequest(RpcRequest):
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
+	def get_CurrentPage(self): # Integer
+		return self.get_query_params().get('CurrentPage')
+
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
