@@ -23,7 +23,7 @@ from aliyunsdksas.endpoint import endpoint_data
 class ModifySecurityEventMarkMissIndividuallyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifySecurityEventMarkMissIndividually')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifySecurityEventMarkMissIndividually','sas')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -41,11 +41,6 @@ class ModifySecurityEventMarkMissIndividuallyRequest(RpcRequest):
 
 	def set_SourceIp(self, SourceIp):  # String
 		self.add_query_param('SourceIp', SourceIp)
-	def get_DeleteMarkMissParam(self): # String
-		return self.get_body_params().get('DeleteMarkMissParam')
-
-	def set_DeleteMarkMissParam(self, DeleteMarkMissParam):  # String
-		self.add_body_params('DeleteMarkMissParam', DeleteMarkMissParam)
 	def get_From(self): # String
 		return self.get_body_params().get('From')
 
@@ -56,3 +51,8 @@ class ModifySecurityEventMarkMissIndividuallyRequest(RpcRequest):
 
 	def set_Lang(self, Lang):  # String
 		self.add_body_params('Lang', Lang)
+	def get_DeleteMarkMissParam(self): # String
+		return self.get_body_params().get('DeleteMarkMissParam')
+
+	def set_DeleteMarkMissParam(self, DeleteMarkMissParam):  # String
+		self.add_body_params('DeleteMarkMissParam', DeleteMarkMissParam)
